@@ -92,11 +92,6 @@ OC.L10N.register(
     "You shared a file which is no longer available" : "Ar restr o peus rannet n'eo ket posupl kavout kenn",
     "%s (guest)" : "%s (kouviat)",
     "You missed a call from {user}" : "C'hwitet o peus ur gemenadenn eus {user}",
-    "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Kemenadenn gant %n kouviad (Padelez {duration})","Kemenadenn gant %n kouviad (Padelez {duration})","Kemenadenn gant %n kouviad (Padelez {duration})","Kemenadenn gant %n kouviad (Padelez {duration})","Kemenadenn gant %n kouviad (Padelez {duration})"],
-    "Call with {user1} and {user2} (Duration {duration})" : "Kemenadenn gant {user1} ha {user2} (Padelez {duration})",
-    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Kemenadenn gant {user1}, {user2} ha {user3} (Padelez {duration})",
-    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Kemenadenn gant {user1}, {user2}, {user3} ha {user4} (Padelez {duration})",
-    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Kemenadenn gant {user1}, {user2}, {user3}, {user4} ha {user5} (Padelez {duration})",
     "Talk to %s" : "Komz da %s",
     "File is not shared, or shared but not with the user" : "N'eo ket rannet ar restr, pe n'eo ket rannet gan an implijour",
     "No account available to delete." : "N'ez eus kont ebet da lemel",
@@ -434,13 +429,14 @@ OC.L10N.register(
     "South Africa" : "Suafrika",
     "Zambia" : "Zambia",
     "Zimbabwe" : "Zimbabwe",
+    "Federation" : "Kevread",
+    "High-performance backend" : "Backend a labour buhan",
     "Invalid date, date format must be YYYY-MM-DD" : "Deizat fall, stumm an deizat a zo ret bezhañ BBBB-MM-DD",
     "Conversation not found" : "N'eo ket bet kavet an diviz",
     "Chat, video & audio-conferencing using WebRTC" : "Chat, video & audio-prezegenn gant WebRTC",
     "Navigating away from the page will leave the call in {conversation}" : "Kuitat ar bajenn a laosko ar pelgomzadenn e {convzersation}",
     "Leave call" : "Kuitat ar gemenadenn",
     "Stay in call" : "Chom er gemenadenn",
-    "Duplicate session" : "Eilan dalc'h",
     "Discuss this file" : "Komz diwar benn ar restr-mañ",
     "Share this file with others to discuss it" : "Rannañ ar restr-mañ da reoù all evit komz diwar e-benn",
     "Share this file" : "Rannañ ar restr",
@@ -467,7 +463,6 @@ OC.L10N.register(
     "Name" : "Anv",
     "Description" : "Deskrivadur",
     "Disabled" : "Disaotreañ",
-    "Federation" : "Kevread",
     "Beta" : "Beta",
     "General settings" : "Stummoù hollek",
     "Default notification settings" : "Arventennoù kemenadennoù dre ziouer",
@@ -509,7 +504,6 @@ OC.L10N.register(
     "Error: Unknown error occurred" : "Fazi : Ur fazi dianv a zo bet",
     "Shared secret" : "Secret rannet",
     "High-performance backend URL" : "URL ar vackend a labour buhan",
-    "High-performance backend" : "Backend a labour buhan",
     "An external signaling server should optionally be used for larger installations. Leave empty to use the internal signaling server." : "Ur servijour diavaezh arhentañ a c'hell bezhañ implijet evit staliadurioù brasoc'h. Laoskit implij ar servijour arhentañ diabarzh goulo.",
     "It is highly recommended to set up a distributed cache when using Nextcloud Talk together with a High Performance Back-end." : "Aliet kreñv eo staliañ ur c'hach rannet pa implijer Nextcloud Talk gant ur Vack-End Labour Huel.",
     "Don't warn about connectivity issues in calls with more than 4 participants" : "N'om pas kemenn diwar ben kudennom kenstagadur er gemennadennoù gant muioc'h eget 4 implijer.",
@@ -557,8 +551,8 @@ OC.L10N.register(
     "Conversation settings" : "Stummoù diviz",
     "Personal" : "Personel",
     "Leave conversation" : "Kuitaat an diviz",
-    "Delete conversation" : "Lemel an diviz",
     "No" : "Nann",
+    "Delete conversation" : "Lemel an diviz",
     "Do you really want to delete \"{displayName}\"?" : "Sur oc'h da lemel  \"{displayName}\" ?",
     "Password protection" : "Gwareziñ gant ur ger-tremen",
     "Copy conversation link" : "Eilañ al liamm diviz",
@@ -567,11 +561,8 @@ OC.L10N.register(
     "Edit" : "Cheñch",
     "More information" : "Muioc'h a ditouroù",
     "Delete" : "Lemel",
-    "User" : "Implijer",
-    "Password" : "Ger-tremen",
-    "Login" : "Anv arveriad",
-    "Client ID" : "ID kliant",
     "Notifications" : "Kemennadennoù",
+    "Login" : "Anv arveriad",
     "Remove from favorites" : "Diverkañañ eus ar pennrolloù",
     "Add to favorites" : "Ouzhpennañ er pennrolloù",
     "You need to promote a new moderator before you can leave the conversation." : "Ret eo deoc'h lakaat unan bennak da moderatour a-rao kuitaat an diviz.",
@@ -592,7 +583,6 @@ OC.L10N.register(
     "No camera" : "Kamera ebet",
     "Upload" : "Pellkas",
     "Files" : "Restroù",
-    "File to share" : "Restr da rannañ",
     "Invalid path selected" : "An hent dibabet n'eus ket anezhañ",
     "Reply" : "Respont",
     "Go to file" : "Mont d'ar restr",
@@ -610,9 +600,10 @@ OC.L10N.register(
     "Error while creating the conversation" : "Ur fazi a zo bet en ur krouiñ an diviz",
     "Password protect" : "Ger-tremen gwarezet",
     "Add emoji" : "Ouzhpennañ un emoji",
+    "File to share" : "Restr da rannañ",
     "Send message" : "Kas ur gemenadenn",
-    "Group" : "Stollad",
     "Share files to the conversation" : "Rannañ restroù d'an diviz",
+    "Share from Files" : "Rannañ diouzh Restroù",
     "New file" : "Restr nevez",
     "Settings" : "Arventennoù",
     "Send" : "Kas",
@@ -683,11 +674,16 @@ OC.L10N.register(
     "Mention myself" : "Meneg ac'hanon",
     "The conversation does not exist" : "N'ez eus ket eus an diviz-mañ",
     "Join a conversation or start a new one!" : "Mont en un diviz pe kregiñ unan nevez !",
+    "Duplicate session" : "Eilan dalc'h",
     "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Deuet oc'h en diviz dre ur prenestr pe ardivink all. N'eo ket douget evit ar poent gant Nextcloud Talk neuze eo bet sertet an dalc'h.",
     "Join a conversation or start a new one" : "Mont en un diviz pe kregiñ unan nevez ",
+    "User" : "Implijer",
+    "Password" : "Ger-tremen",
+    "Client ID" : "ID kliant",
     "Media" : "Media",
     "Audio" : "Audio",
     "Other" : "All",
+    "Group" : "Stollad",
     "You: {lastMessage}" : "C'hwi : {lastMessage}",
     "{actor}: {lastMessage}" : "{actor} : {lastMessage}",
     "Nextcloud Talk was updated, please reload the page" : "Adnevesaet eo bet Nextcloud Talk , adkargit ar bajenn",
@@ -725,6 +721,11 @@ OC.L10N.register(
     "There are currently no commands available." : "N'ez us linenn urzh ebet evit ar poent",
     "The command does not exist" : "N'ez eus ket eyus an urzh",
     "An error occurred while running the command. Please ask an administrator to check the logs." : "Ur fazi a zo bet en ur ober an urzh. Goulennit d'ar merour da sellet ouzh ar gazetenn.",
+    "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Kemenadenn gant %n kouviad (Padelez {duration})","Kemenadenn gant %n kouviad (Padelez {duration})","Kemenadenn gant %n kouviad (Padelez {duration})","Kemenadenn gant %n kouviad (Padelez {duration})","Kemenadenn gant %n kouviad (Padelez {duration})"],
+    "Call with {user1} and {user2} (Duration {duration})" : "Kemenadenn gant {user1} ha {user2} (Padelez {duration})",
+    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Kemenadenn gant {user1}, {user2} ha {user3} (Padelez {duration})",
+    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Kemenadenn gant {user1}, {user2}, {user3} ha {user4} (Padelez {duration})",
+    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Kemenadenn gant {user1}, {user2}, {user3}, {user4} ha {user5} (Padelez {duration})",
     "Commands" : "Urzhioù",
     "Command" : "Urzh",
     "Script" : "Script",
@@ -740,7 +741,6 @@ OC.L10N.register(
     "Add users, groups or circles" : "Ouhzpennañ implijourienn, strolladoù pe kelc'hioù",
     "Add users or circles" : "Ouhzpennañ implijourienn pe kelc'hioù",
     "Add groups or circles" : "Ouhzpennañ strolladoù pe kelc'hioù",
-    "Open sidebar" : "Digori ar varenn gostez",
     "Start a conversation" : "Kregiñ un diviz",
     "Specify commands the users can use in chats" : "Lakait peseurt urzhioù eo posupl d'an implijer implij er chat",
     "TURN server" : "Servijour TRUN",
