@@ -69,11 +69,6 @@ OC.L10N.register(
     "You shared a file which is no longer available" : "Compartiste un archivo que ya no está disponible",
     "Message deleted by author" : "Mensaje eliminado por el autor",
     "%s (guest)" : "%s (invitado)",
-    "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Llamada con %n invitado (Duración {duration})","Llamada con %n invitados (Duración {duration})","Llamada con %n invitados (Duración {duration})"],
-    "Call with {user1} and {user2} (Duration {duration})" : "Llamada con {user1} y {user2} (Duración {duration})",
-    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Llamada con {user1}, {user2} y {user3} (Duración {duration})",
-    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Llamada con {user1}, {user2}, {user3} y {user4} (Duración {duration})",
-    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Llamada con {user1}, {user2}, {user3}, {user4} y {user5} (Duración {duration})",
     "Talk conversations" : "Conversaciones de Talk",
     "Talk to %s" : "Hablar con %s",
     "File is not shared, or shared but not with the user" : "Archivo no compartido, o compartido pero no con el usuario.",
@@ -320,6 +315,7 @@ OC.L10N.register(
     "South Africa" : "Sudáfrica",
     "Zambia" : "Zambia",
     "Zimbabwe" : "Zimbabue",
+    "Federation" : "Federación",
     "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
     "Leave call" : "Dejar la llamada",
     "This conversation has ended" : "Esta conversación ha terminado",
@@ -333,7 +329,6 @@ OC.L10N.register(
     "Description" : "Descripción",
     "Enabled" : "Habilitado",
     "Disabled" : "Deshabilitado",
-    "Federation" : "Federación",
     "Beta" : "Beta",
     "Permissions" : "Permisos",
     "General settings" : "Configuraciones generales",
@@ -356,6 +351,7 @@ OC.L10N.register(
     "Failed" : "Falló",
     "OK" : "OK",
     "Checking …" : "Verificando ...",
+    "Federated user" : "Usuario federado",
     "Back" : "Atrás",
     "Cancel" : "Cancelar",
     "Confirm" : "Confirmar",
@@ -394,15 +390,9 @@ OC.L10N.register(
     "Edit" : "Editar",
     "Delete" : "Eliminar",
     "Log content" : "Contenido de bitácoras",
-    "Talk conversation" : "Conversación de Talk",
-    "User" : "Usuario",
-    "Password" : "Contraseña",
-    "API token" : "Ficha del API",
-    "Login" : "Iniciar sesión",
-    "Nickname" : "Apodo",
-    "Client ID" : "ID del cliente",
     "Notifications" : "Notificaciones",
     "Enter your name" : "Ingrese su nombre",
+    "Login" : "Iniciar sesión",
     "Remove from favorites" : "Eliminar de favoritos",
     "Add to favorites" : "Agregar a favoritos",
     "Clear filter" : "Limpiar filtro",
@@ -423,20 +413,25 @@ OC.L10N.register(
     "Reply" : "Responder",
     "Set reminder" : "Establecer recordatorio",
     "Translate" : "Traducir",
+    "Set reminder for later today" : "Configurar recordatorio para hoy, más tarde",
+    "Set reminder for tomorrow" : "Configurar recordatorio para mañana",
+    "Set reminder for this weekend" : "Configurar recordatorio para este fin de semana",
+    "Set reminder for next week" : "Configurar recordatorio para la próxima semana",
     "Dismiss" : "Descartar",
     "Translate from" : "Traducir desde",
     "Contact" : "Contacto",
     "Copy code block" : "Copiar bloque de código",
+    "No messages" : "Sin mensajes",
     "Today" : "Hoy",
     "Yesterday" : "Ayer",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "_%n day ago_::_%n days ago_" : ["hace %n día","hace %n días","hace %n días"],
     "Close" : "Cerrar",
     "Password protect" : "Proteger con contraseña",
-    "Group" : "Grupo",
     "Upload from device" : "Cargar desde el dispositivo",
     "Create new poll" : "Crear nueva encuesta",
     "Smart picker" : "Selector inteligente",
+    "Share from Files" : "Compartir desde Archivos",
     "New file" : "Archivo nuevo",
     "Blank" : "Vacío",
     "Settings" : "Configuraciones ",
@@ -475,13 +470,21 @@ OC.L10N.register(
     "Grid view" : "Vista de cuadrícula",
     "Submit" : "Enviar",
     "Join a conversation or start a new one" : "Únete a la conversación o incia una nueva",
+    "Talk conversation" : "Conversación de Talk",
+    "User" : "Usuario",
+    "Password" : "Contraseña",
+    "API token" : "Ficha del API",
+    "Nickname" : "Apodo",
+    "Client ID" : "ID del cliente",
     "Media" : "Multimedia",
     "Polls" : "Encuestas",
     "Locations" : "Ubicaciones",
     "Audio" : "Audio",
     "Other" : "Otro",
     "Show all files" : "Mostrar todos los archivos",
+    "Group" : "Grupo",
     "Error while sharing file" : "Error al compartir el archivo",
+    "Error while parsing a PROPFIND error" : "Error al analizar un error PROPFIND",
     "Do not disturb" : "No molestar",
     "Away" : "Ausente",
     "Default" : "Predeterminado",
@@ -498,10 +501,14 @@ OC.L10N.register(
     "There are currently no commands available." : "No hay comandos disponibles actualmente",
     "The command does not exist" : "El comando no existe",
     "An error occurred while running the command. Please ask an administrator to check the logs." : "Ocurrió un error al ejecutar el comando. Por favor solicite al administrador revisar los logs",
+    "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Llamada con %n invitado (Duración {duration})","Llamada con %n invitados (Duración {duration})","Llamada con %n invitados (Duración {duration})"],
+    "Call with {user1} and {user2} (Duration {duration})" : "Llamada con {user1} y {user2} (Duración {duration})",
+    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Llamada con {user1}, {user2} y {user3} (Duración {duration})",
+    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Llamada con {user1}, {user2}, {user3} y {user4} (Duración {duration})",
+    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Llamada con {user1}, {user2}, {user3}, {user4} y {user5} (Duración {duration})",
     "More unread mentions" : "Más menciones no leídas",
     "Command" : "Comando",
     "Circles" : "Círculos",
-    "Open sidebar" : "Abrir barra lateral",
     "TURN server" : "Servidor TURN",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "El servidor TURN se usa para concentrar el tráfico de participantes detras de un firewall. ",
     "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Un servidor externo de señalización puede ser, opcionalmente, utilizado para instalaciones más grandes. Déjalo vacío para usar el sevidor de señalización interno. "
