@@ -144,16 +144,11 @@ OC.L10N.register(
     "%s (guest)" : "%s (convidat)",
     "You missed a call from {user}" : "Avètz mancat una sonada de {user}",
     "You tried to call {user}" : "Avètz ensajat de sonar {user}",
-    "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Sonada amb %n convidat (Durada {duration})","Sonada amb %n convidats (Durada {duration})"],
     "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} acabèt la sonada amb %n convidat (Durada {duration})","{actor} acabèt la sonada amb %n convidats (Durada {duration})"],
-    "Call with {user1} and {user2} (Duration {duration})" : "Sonada amb {user1} e {user2} (Durada {duration})",
     "{actor} ended the call with {user1} (Duration {duration})" : "{actor} acabèt la sonada amb {user1} (Durada {duration})",
     "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} acabèt la sonada amb {user1} e {user2} (Durada {duration})",
-    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Sonada amb {user1}, {user2} e {user3} (Durada {duration})",
     "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} acabèt la sonada amb {user1}, {user2} e {user3} (Durada {duration})",
-    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Sonada amb {user1}, {user2}, {user3} e {user4} (Durada {duration})",
     "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} acabèt la sonada amb {user1}, {user2}, {user3} e {user4} (Durada {duration})",
-    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Sonada amb {user1}, {user2}, {user3}, {user4} e {user5} (Durada {duration})",
     "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} acabèt la sonada amb {user1}, {user2}, {user3}, {user4} {user5} (Durada {duration})",
     "Message of {user} in {conversation}" : "Messatge de {user} dins {conversation}",
     "Message of {user}" : "Messatge de {user}",
@@ -505,7 +500,6 @@ OC.L10N.register(
     "Chat, video & audio-conferencing using WebRTC" : "Messatjariá, conferéncias vidèo e àudio amb WebRTC",
     "Leave call" : "Quitar la sonada",
     "Stay in call" : "Demorar en linha",
-    "Duplicate session" : "Duplicar la session",
     "Discuss this file" : "Discutir d’aqueste fichièr",
     "Share this file with others to discuss it" : "Partejar aqueste fichièr amb d’autres per ne discutir",
     "Share this file" : "Partejar aqueste fichièr",
@@ -599,8 +593,8 @@ OC.L10N.register(
     "Cancel" : "Anullar",
     "Confirm" : "Confirmar",
     "Reset" : "Reïnicializar",
-    "Post message" : "Publicar messatge",
-    "The message could not be sent" : "Se podiá pas enviar lo messatge",
+    "Add participant \"{user}\"" : "Apondre participant « {user} »",
+    "This conversation is read-only" : "Aquesta conversacion es en lectura sola",
     "{nickName} raised their hand." : "{nickName} a levat la man.",
     "A participant raised their hand." : "Un participant a levat la man.",
     "Previous page of videos" : "Pagina de vidèos precedenta",
@@ -643,8 +637,8 @@ OC.L10N.register(
     "Collapse" : "Replegar",
     "Conversation messages" : "Messatges de conversacion",
     "Scroll to bottom" : "Defilar enbàs",
+    "Post message" : "Publicar messatge",
     "You need to be logged in to upload files" : "Devètz èsser autentificat per enviar de fichièrs",
-    "This conversation is read-only" : "Aquesta conversacion es en lectura sola",
     "Drop your files to upload" : "Depausatz los fichièrs d’enviar",
     "Favorite" : "Favorit",
     "Loading …" : "Cargament…",
@@ -675,10 +669,10 @@ OC.L10N.register(
     "Be careful, these actions cannot be undone." : "Fasètz atencion, aquelas accions pòdon pas èsser anulladas.",
     "Leave conversation" : "Quitar la conversacion",
     "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Un còp quitada, per tornar a un conversacion tampada, cal un convit. Una conversacion dubèrta es totjorn accessibla.",
-    "Delete conversation" : "Suprimir la conversacion",
-    "Permanently delete this conversation." : "Suprimir permanent aquesta conversacion",
     "No" : "Non",
     "Yes" : "Òc",
+    "Delete conversation" : "Suprimir la conversacion",
+    "Permanently delete this conversation." : "Suprimir permanent aquesta conversacion",
     "Delete chat messages" : "Suprimir los messatges del chat",
     "Permanently delete all the messages in this conversation." : "Suprimir per totjorn totes los messatges d’aquesta conversacion.",
     "Delete all chat messages" : "Suprimir totes los messatges del chat",
@@ -695,11 +689,6 @@ OC.L10N.register(
     "Save password" : "Enregistrar lo senhal",
     "Copy conversation link" : "Copiar lo ligam de conversacion",
     "Resend invitations" : "Tornar enviar las invitacions",
-    "Conversation password has been saved" : "Lo senhal de conversacion es estat enregistrat",
-    "Conversation password has been removed" : "Lo senhal de conversacion es estat suprimit",
-    "Error occurred while saving conversation password" : "Error pendent l'enregistrament del senhal de la conversacion",
-    "Invitations sent" : "Invitacions enviadas",
-    "Error occurred when sending invitations" : "Error en enviant las invitacions",
     "Open conversation" : "Dobrir la conversacion",
     "Error occurred when opening or limiting the conversation" : "Error en dobrissent o limitant la conversacion",
     "Meeting start time" : "Ora de debuta de la conferéncia",
@@ -719,49 +708,6 @@ OC.L10N.register(
     "More info on Matterbridge" : "Mai d’info sus Matterbridge",
     "Enable bridge" : "Activar lo pont",
     "Show Matterbridge log" : "Veire los jornals de Matterbridge",
-    "Nextcloud URL" : "URL Nextcloud",
-    "Nextcloud user" : "Utilizaire Nextcloud",
-    "User password" : "Senhal utilizaire",
-    "Talk conversation" : "Conversacion Talk",
-    "Matrix server URL" : "URL servidor Matrix",
-    "User" : "User",
-    "Matrix channel" : "Cadena Matrix",
-    "Mattermost server URL" : "URL servidor Mattermost",
-    "Mattermost user" : "Utilizaire Mattermost",
-    "Team name" : "Nom de la còla",
-    "Channel name" : "Nom de la cadena",
-    "Rocket.Chat server URL" : "URL del servidor Rocket.Chat",
-    "User name or email address" : "Nom d’utilizaire o adreça email",
-    "Password" : "Senhal",
-    "Rocket.Chat channel" : "Canal Rocket.Chat",
-    "Skip TLS verification" : "Passar la verificacion TLS",
-    "Zulip server URL" : "URL servidor Zulip",
-    "Bot user name" : "Nom d’utilizaire robòt",
-    "Bot API key" : "Clau d’API robòt",
-    "Zulip channel" : "Canal Zulip",
-    "API token" : "Geton API",
-    "Slack channel" : "Canal Slack",
-    "Server ID or name" : "ID o nom del servidor",
-    "Channel ID or name" : "ID o nom del canal",
-    "Channel" : "Cadena",
-    "Login" : "Login",
-    "Chat ID" : "ID del chat",
-    "IRC server URL (e.g. chat.freenode.net:6667)" : "URL servidor IRC (per exemple chat.freenode.net:6667)",
-    "Nickname" : "Escais",
-    "Connection password" : "Senhal de connexion",
-    "IRC channel" : "Cadena IRC",
-    "Channel password" : "Senhal de cadena",
-    "NickServ nickname" : "Nom d’utilizaire NickServ",
-    "NickServ password" : "Senhal NickServ",
-    "Use TLS" : "Utilizar TLS",
-    "Use SASL" : "Utilizar SASL",
-    "Tenant ID" : "ID Tenant",
-    "Client ID" : "ID client",
-    "Team ID" : "ID Team",
-    "Thread ID" : "ID fial",
-    "XMPP/Jabber server URL" : "URL servidor XMPP/Jabber",
-    "MUC server URL" : "URL servidor MUC",
-    "Jabber ID" : "ID Jabber",
     "unknown state" : "estat desconegut",
     "running" : "en cors d'execucion",
     "not running" : "pas en execucion",
@@ -770,6 +716,7 @@ OC.L10N.register(
     "Notify about calls in this conversation" : "Notificar las sonadas d’aquesta conversacion",
     "Recording Consent" : "Consentiment d'enregistrament",
     "Enter your name" : "Picatz vòstre nom",
+    "Login" : "Login",
     "Creating the conversation …" : "Creacion de la conversacion...",
     "Conversation actions" : "Accions de conversacion",
     "Mark as read" : "Marcar coma legit",
@@ -807,7 +754,6 @@ OC.L10N.register(
     "No camera" : "Cap de camèra",
     "Upload" : "Cargament",
     "Files" : "Fichièrs",
-    "File to share" : "Fichièr de partejar",
     "Invalid path selected" : "Camin seleccionat invalid",
     "Unread messages" : "Messatges pas legits",
     "Message read by everyone who shares their reading status" : "Messatge legit per tot lo monde que partejan lo estatut de lectura",
@@ -868,11 +814,12 @@ OC.L10N.register(
     "Enter password" : "Picar lo senhal",
     "Add emoji" : "Apondre emoji",
     "Cancel editing" : "Anullar la modificacion",
+    "File to share" : "Fichièr de partejar",
     "This conversation has been locked" : "Aquesta conversacion foguèt clavada",
     "Joining conversation …" : "Dintra dins la conversacion…",
     "Send message" : "Enviar un messatge",
-    "Group" : "Grop",
     "Share files to the conversation" : "Partejar de fichièrs dins la conversacion",
+    "Share from Files" : "Partejar a partir dels Fichièrs",
     "Record voice message" : "Enregistrar messatge vocal",
     "End recording and send" : "Acabar àudio e enviar",
     "Dismiss recording" : "Anullar l’enregistrament",
@@ -889,14 +836,12 @@ OC.L10N.register(
     "Delete poll option" : "Suprimir l’opcion de sondatge",
     "Add answer" : "Apondre responsa",
     "Settings" : "Paramètres",
-    "Private poll" : "Sondatge privat",
     "Multiple answers" : "Multi responsas",
     "Create poll" : "Crear un sondatge",
     "Someone is typing …" : "Qualqu’un pica...",
     "{user1} is typing …" : "{user1} pica…",
     "{user1} and {user2} are typing …" : "{user1} e {user2} pican…",
     "{user1}, {user2} and {user3} are typing …" : "{user1}, {user2} e {user3} pican…",
-    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}, {user2}, {user3} e %n autre pican…","{user1}, {user2}, {user3} e %n autres pican…"],
     "Send" : "Mandar",
     "Add more files" : "Apondre mai de fichièrs",
     "Start a call" : "Començar una sonada",
@@ -923,7 +868,6 @@ OC.L10N.register(
     "Remove all permissions" : "Suprimir totas las permissions",
     "Remove" : "Suprimir",
     "Settings for participant \"{user}\"" : "Paramètres pel participant « {user} »",
-    "Add participant \"{user}\"" : "Apondre participant « {user} »",
     "Participant \"{user}\"" : "Participant « {user} »",
     "Raised their hand" : "Levèt la man",
     "Joined with video" : "Rejonhèt amb vidèo",
@@ -931,7 +875,6 @@ OC.L10N.register(
     "Joined with audio" : "Rejonhèt amb l’àudio",
     "Remove group and members" : "Levar de grops e membres",
     "Remove participant" : "Tirar participant",
-    "Could not send invitation to {actorId}" : "Mandadís impossible del convit a {actorId}",
     "Permissions granted to {displayName}" : "Autorizacions acordadas a {displayName}",
     "Permissions removed for {displayName}" : "Permissions suprimidas per {displayName}",
     "Permissions set to default for {displayName}" : "Permissions definidas a defaut per {displayName}",
@@ -1053,9 +996,52 @@ OC.L10N.register(
     "Mention myself" : "Me mencionar",
     "The conversation does not exist" : "La conversacion existís pas",
     "Join a conversation or start a new one!" : "Rejonhètz una conversacion o creatz-ne una !",
+    "Duplicate session" : "Duplicar la session",
     "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Avètz rejonch la conversacion dins una autra fenèstra o periferic. Aquò es actualament pas pres en cargar per Nextcloud Talk doncas aquesta session es estada tampada.",
-    "Tomorrow – {timeLocale}" : "Deman – {timeLocale}",
     "Join a conversation or start a new one" : "Rejónher una conversacion o ne crear una",
+    "Tomorrow – {timeLocale}" : "Deman – {timeLocale}",
+    "Nextcloud URL" : "URL Nextcloud",
+    "Nextcloud user" : "Utilizaire Nextcloud",
+    "User password" : "Senhal utilizaire",
+    "Talk conversation" : "Conversacion Talk",
+    "Skip TLS verification" : "Passar la verificacion TLS",
+    "Matrix server URL" : "URL servidor Matrix",
+    "User" : "User",
+    "Matrix channel" : "Cadena Matrix",
+    "Mattermost server URL" : "URL servidor Mattermost",
+    "Mattermost user" : "Utilizaire Mattermost",
+    "Team name" : "Nom de la còla",
+    "Channel name" : "Nom de la cadena",
+    "Rocket.Chat server URL" : "URL del servidor Rocket.Chat",
+    "User name or email address" : "Nom d’utilizaire o adreça email",
+    "Password" : "Senhal",
+    "Rocket.Chat channel" : "Canal Rocket.Chat",
+    "Zulip server URL" : "URL servidor Zulip",
+    "Bot user name" : "Nom d’utilizaire robòt",
+    "Bot API key" : "Clau d’API robòt",
+    "Zulip channel" : "Canal Zulip",
+    "API token" : "Geton API",
+    "Slack channel" : "Canal Slack",
+    "Server ID or name" : "ID o nom del servidor",
+    "Channel ID or name" : "ID o nom del canal",
+    "Channel" : "Cadena",
+    "Chat ID" : "ID del chat",
+    "IRC server URL (e.g. chat.freenode.net:6667)" : "URL servidor IRC (per exemple chat.freenode.net:6667)",
+    "Nickname" : "Escais",
+    "Connection password" : "Senhal de connexion",
+    "IRC channel" : "Cadena IRC",
+    "Channel password" : "Senhal de cadena",
+    "NickServ nickname" : "Nom d’utilizaire NickServ",
+    "NickServ password" : "Senhal NickServ",
+    "Use TLS" : "Utilizar TLS",
+    "Use SASL" : "Utilizar SASL",
+    "Tenant ID" : "ID Tenant",
+    "Client ID" : "ID client",
+    "Team ID" : "ID Team",
+    "Thread ID" : "ID fial",
+    "XMPP/Jabber server URL" : "URL servidor XMPP/Jabber",
+    "MUC server URL" : "URL servidor MUC",
+    "Jabber ID" : "ID Jabber",
     "Media" : "Mèdia",
     "Polls" : "Sondatges",
     "Voice messages" : "Messatges àudio",
@@ -1070,6 +1056,7 @@ OC.L10N.register(
     "Show all call recordings" : "Mostrar los enregistraments de sonadas",
     "Show all audio" : "Veire totes los àudios",
     "Show all other" : "Veire tota la rèsta",
+    "Group" : "Grop",
     "You: {lastMessage}" : "Vos : {lastMessage}",
     "{actor}: {lastMessage}" : "{actor} : {lastMessage}",
     "Nextcloud Talk was updated, please reload the page" : "Nextcloud Talk foguèt mes a jorn, mercés de tornar cargar la pagina",
@@ -1077,11 +1064,17 @@ OC.L10N.register(
     "Error while clearing conversation history" : "Error pendent escafament de l’istoric de la conversacion",
     "Error occurred while allowing guests" : "Error en autorizant los convidats",
     "Error occurred while disallowing guests" : "Error en autorizant pas mai los convidats",
+    "Conversation password has been saved" : "Lo senhal de conversacion es estat enregistrat",
+    "Conversation password has been removed" : "Lo senhal de conversacion es estat suprimit",
+    "Error occurred while saving conversation password" : "Error pendent l'enregistrament del senhal de la conversacion",
     "Error while uploading file \"{fileName}\"" : "Error en enviant lo fichièr « {fileName} »",
     "Not enough free space to upload file \"{fileName}\"" : "Pas pro d’espaci liure per enviar lo fichièr « {fileName} »",
     "An error happened when trying to share your file" : "Una error s’es producha en ensajant de partejar vòstre fichièr",
     "Could not post message: {errorMessage}" : "Fracàs de la publicacion : {errorMessage}",
     "An error occurred while fetching the participants" : "Una error s’es producha en recuperant los participants",
+    "Could not send invitation to {actorId}" : "Mandadís impossible del convit a {actorId}",
+    "Invitations sent" : "Invitacions enviadas",
+    "Error occurred when sending invitations" : "Error en enviant las invitacions",
     "Failed to join the conversation. Try to reload the page." : "Impossible de rejónher la conversacion. Ensajatz de recargar la pagina.",
     "Join here" : "Rejónher aquí",
     "Leave this page" : "Quitar aquesta pagina",
@@ -1122,6 +1115,11 @@ OC.L10N.register(
     "{actor} removed circle {circle}" : "{actor} tirèt lo cercle {circle}",
     "You removed circle {circle}" : "Avètz tirat lo cercle {circle}",
     "An administrator removed circle {circle}" : "Un administrator tirèt lo cercle {circle}",
+    "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Sonada amb %n convidat (Durada {duration})","Sonada amb %n convidats (Durada {duration})"],
+    "Call with {user1} and {user2} (Duration {duration})" : "Sonada amb {user1} e {user2} (Durada {duration})",
+    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Sonada amb {user1}, {user2} e {user3} (Durada {duration})",
+    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Sonada amb {user1}, {user2}, {user3} e {user4} (Durada {duration})",
+    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Sonada amb {user1}, {user2}, {user3}, {user4} e {user5} (Durada {duration})",
     "More unread mentions" : "Mai de mencions non legidas",
     "{user1} shared room {roomName} on {remoteServer} with you" : "{user1} a partejat la sala {roomName} sus {remoteServer} amb vos",
     "Commands" : "Comandas",
@@ -1130,15 +1128,16 @@ OC.L10N.register(
     "Response to" : "Respondre a",
     "Enabled for" : "Activat per",
     "Moderators" : "Moderators",
+    "The message could not be sent" : "Se podiá pas enviar lo messatge",
     "Delete Conversation" : "Suprimir la conversacion",
     "Circles" : "Cercles",
     "Users and circles" : "Utilizaires e cercles",
     "Groups and circles" : "Grops e cercles",
+    "Private poll" : "Sondatge privat",
     "Add circles" : "Apondre cercles",
     "Add users, groups or circles" : "Apondre utilizaires, grops o cercles",
     "Add users or circles" : "Apondre utilizaires o cercles",
     "Add groups or circles" : "Apondre grops o cercles",
-    "Open sidebar" : "Dobrir panèl lateral",
     "Start a conversation" : "Començar una conversacion",
     "Post to conversation" : "Publicar a la conversacion",
     "Share to conversation" : "Partejar dins una conversacion",
