@@ -113,14 +113,10 @@ OC.L10N.register(
     "Unknown number" : "Număr necunoscut",
     "You missed a call from {user}" : "Ați pierdut un apel de la {user}",
     "You tried to call {user}" : "Ați încercat să apelați pe {user}",
-    "Call with {user1} and {user2} (Duration {duration})" : "Apel cu {user1} și {user2} (Durată {duration})",
     "{actor} ended the call with {user1} (Duration {duration})" : "{actor} a închis apelul cu {user1} (Durată {duration})",
     "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} a închis apelul cu {user1} și {user2} (Durată {duration})",
-    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Apelul cu {user1}, {user2} și {user3} (Durată {duration})",
     "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} a încheiat apelul cu {user1}, {user2} și {user3} (Durată {duration})",
-    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Apel cu {user1}, {user2}, {user3} și {user4} (Durată {duration})",
     "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} a încheiat apelul cu {user1}, {user2}, {user3} și {user4} (Durată {duration})",
-    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Apel cu {user1}, {user2}, {user3}, {user4} și {user5} (Durată {duration})",
     "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} a încheiat apelul cu {user1}, {user2}, {user3}, {user4} și {user5} (Durată {duration})",
     "Message of {user} in {conversation}" : "Mesaj al {user} în {conversation}",
     "Message of {user}" : "Mesaj al {user}",
@@ -434,12 +430,12 @@ OC.L10N.register(
     "South Africa" : "South Africa",
     "Zambia" : "Zambia",
     "Zimbabwe" : "Zimbabwe",
+    "Federation" : "Federare",
     "Invalid date, date format must be YYYY-MM-DD" : "Dată invalidă, formatul trebuie să fie AAAA-LL-ZZ",
     "Conversation not found" : "Conversație negăsită",
     "Navigating away from the page will leave the call in {conversation}" : "Părăsind pagina se va părăsi conversația {conversation}",
     "Leave call" : "Părăsește videoconferința",
     "Stay in call" : "Rămâneți în videoconferință",
-    "Duplicate session" : "Sesiune duplicat",
     "Discuss this file" : "Discutați acest fișier",
     "Share this file with others to discuss it" : "Partajați acest fișier cu ceilalți pentru a-l discuta",
     "Share this file" : "Partajați acest fișier",
@@ -468,7 +464,6 @@ OC.L10N.register(
     "Locked for moderators" : "Blocat pentru moderatori",
     "Enabled" : "Activat",
     "Disabled" : "Dezactivați",
-    "Federation" : "Federare",
     "Beta" : "Beta",
     "Permissions" : "Permisiuni",
     "All messages" : "Toate mesajele",
@@ -494,7 +489,8 @@ OC.L10N.register(
     "Cancel" : "Anulare",
     "Confirm" : "Confirmă",
     "Reset" : "Resetare",
-    "The message could not be sent" : "Mesajul nu s-a putut transmite ",
+    "Add participant \"{user}\"" : "Adaugă participant \"{user}\"",
+    "This conversation is read-only" : "Această conversație este read-only",
     "{nickName} raised their hand." : "{nickName} a ridicat mâna.",
     "A participant raised their hand." : "Un participant a ridicat mâna.",
     "Copy link" : "Copiză link",
@@ -532,7 +528,6 @@ OC.L10N.register(
     "Conversation messages" : "Mesajele conversației",
     "Scroll to bottom" : "Derulează la sfârșit",
     "You need to be logged in to upload files" : "Trebuie să fiți autentificat pentru a încărca fișiere",
-    "This conversation is read-only" : "Această conversație este read-only",
     "Drop your files to upload" : "Trageți fișierele pentru încărcare",
     "Favorite" : "Favorite",
     "Hide details" : "Ascunde detaliile",
@@ -565,10 +560,10 @@ OC.L10N.register(
     "Meeting" : "Videoconferință",
     "Leave conversation" : "Părăsiți conversația",
     "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Odată ce ați părăsit o conversație, pentru a vă realătura aveți nevoie de o invitație. Conversațiile deschise pot fi accesate oricând.",
-    "Delete conversation" : "Șterge conversația",
-    "Permanently delete this conversation." : "Șterge permanent conversația",
     "No" : "Nu",
     "Yes" : "Da",
+    "Delete conversation" : "Șterge conversația",
+    "Permanently delete this conversation." : "Șterge permanent conversația",
     "Delete chat messages" : "Șterge mesajele de chat",
     "Permanently delete all the messages in this conversation." : "Șterge permanent toate mesajele din conversație",
     "Delete all chat messages" : "Șterge toate mesajele de chat",
@@ -587,9 +582,6 @@ OC.L10N.register(
     "Save password" : "Salvează parola",
     "Copy conversation link" : "Copiază linkul conversației",
     "Resend invitations" : "Trimite din nou invitațiile",
-    "Conversation password has been saved" : "Parola conversației a fost salvată",
-    "Conversation password has been removed" : "Parola conversație a fost ștearsă",
-    "Invitations sent" : "Invitațiile au fost trimise",
     "Open conversation" : "Deschide conversația",
     "Error occurred when opening or limiting the conversation" : "Eroare la deschiderea sau la limitarea conversației ",
     "Meeting start time" : "Ora de început a videoconferinței",
@@ -602,15 +594,10 @@ OC.L10N.register(
     "Edit" : "Editează",
     "More information" : "Mai multe informații",
     "Delete" : "Șterge",
-    "Talk conversation" : "Conversație Talk",
-    "User" : "Utilizator",
-    "Password" : "Parolă",
-    "Login" : "Autentificare",
-    "Nickname" : "Pseudonim",
-    "Client ID" : "ID client",
     "Notifications" : "Notificări",
     "Enter your name" : "Introduceți numele",
     "Submit name and join" : "Transmite numele și participați",
+    "Login" : "Autentificare",
     "Search participants or phone numbers" : "Căutare participanți sau numere de telefon",
     "Creating the conversation …" : "Se creează conversația ...",
     "Conversation actions" : "Acțiuni conversație",
@@ -644,7 +631,6 @@ OC.L10N.register(
     "Blur" : "Blurează",
     "Upload" : "Încărcare",
     "Files" : "Fișiere",
-    "File to share" : "Fișier de partajat",
     "Invalid path selected" : "Calea selectată este invalidă",
     "Message sent" : "Mesajul a fost transmis",
     "Reply" : "Răspunde",
@@ -674,11 +660,13 @@ OC.L10N.register(
     "Password protect" : "Protejare cu parolă",
     "Enter password" : "Introduceți parola",
     "Cancel editing" : "Anulează editarea",
+    "File to share" : "Fișier de partajat",
     "Joining conversation …" : "Alăturare la conversație ...",
-    "Group" : "Grup",
     "Upload from device" : "Încarcă din dispozitiv",
+    "Share from Files" : "Partajează din Fișiere",
     "New file" : "Fișier nou",
     "Blank" : "Gol",
+    "Question" : "Întrebare",
     "Settings" : "Setări",
     "Send" : "Trimite",
     "guest" : "invitat",
@@ -690,17 +678,11 @@ OC.L10N.register(
     "Remove all permissions" : "Elimină toate permisiunile",
     "Remove" : "Elimină",
     "Settings for participant \"{user}\"" : "Setări pentru  participant \"{user}\"",
-    "Add participant \"{user}\"" : "Adaugă participant \"{user}\"",
-    "Clear reminder – {timeLocale}" : "Șterge memento – {timeLocale}",
-    "Next week – {timeLocale}" : "Săptămâna viitoare– {timeLocale}",
-    "This weekend – {timeLocale}" : "În acest weekend – {timeLocale}",
     "Ringing …" : "Apel …",
     "Raised their hand" : "Au ridicat mâna",
     "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "Textul trebuie să fie mai scurt sau egal cu {maxLength} caractere. Textul curent are {charactersCount} caractere.",
     "Remove group and members" : "Elimină grup și membri",
     "Remove participant" : "Elimină participant",
-    "Invitation was sent to {actorId}" : "Invitația a fost trimisă către {actorId}",
-    "Could not send invitation to {actorId}" : "Nu a fost trimisă invitația către {actorId}",
     "Notification was sent to {displayName}" : "Notificarea a fost trimisă către {displayName}",
     "Could not send notification to {displayName}" : "Nu a fost trimisă notificarea către {displayName}",
     "Permissions granted to {displayName}" : "Permisiunile au fost acordate {displayName}",
@@ -719,6 +701,7 @@ OC.L10N.register(
     "Add other sources" : "Adaugă alte surse",
     "Participants" : "Participanți",
     "Search or add participants" : "Căutare sau adăugare participanți",
+    "Invitation was sent to {actorId}" : "Invitația a fost trimisă către {actorId}",
     "An error occurred while adding the participants" : "Eroare la adăugarea participanților",
     "Details" : "Detalii",
     "Shared items" : "Elemente partajate",
@@ -818,9 +801,18 @@ OC.L10N.register(
     "Mention myself" : "Mă menționez",
     "The conversation does not exist" : "Conversația nu există",
     "Join a conversation or start a new one!" : "Particiăați la o conversație sau creați una nouă!",
-    "Tomorrow – {timeLocale}" : "Mâine – {timeLocale}",
+    "Duplicate session" : "Sesiune duplicat",
     "Join a conversation or start a new one" : "Participați la o conversație sau începeți una nouă",
+    "Clear reminder – {timeLocale}" : "Șterge memento – {timeLocale}",
+    "Next week – {timeLocale}" : "Săptămâna viitoare– {timeLocale}",
+    "This weekend – {timeLocale}" : "În acest weekend – {timeLocale}",
+    "Tomorrow – {timeLocale}" : "Mâine – {timeLocale}",
     "Later today – {timeLocale}" : "Azi, mai târziu – {timeLocale}",
+    "Talk conversation" : "Conversație Talk",
+    "User" : "Utilizator",
+    "Password" : "Parolă",
+    "Nickname" : "Pseudonim",
+    "Client ID" : "ID client",
     "Media" : "Media",
     "Polls" : "Voturi",
     "Deck cards" : "Carduri Deck",
@@ -836,6 +828,7 @@ OC.L10N.register(
     "Show all locations" : "Arată toate locațiile",
     "Show all audio" : "Arată audio",
     "Show all other" : "Arată celelalte",
+    "Group" : "Grup",
     "You reconnected to the call" : "V-ați reconectat",
     "{actor} reconnected to the call" : "{actor} s-a reconectat",
     "You added {user0} and {user1}" : "Ați adăugat pe {user0} și {user1}",
@@ -847,6 +840,8 @@ OC.L10N.register(
     "Deck card has been posted to {conversation}" : "Cardul Deck a fost postat la conversația {conversation}",
     "Error while sharing file" : "Eroare la partajarea fișierului",
     "Error while clearing conversation history" : "Eroare la ștergerea istoricului conversației",
+    "Conversation password has been saved" : "Parola conversației a fost salvată",
+    "Conversation password has been removed" : "Parola conversație a fost ștearsă",
     "Conversation picture set" : "Imaginea conversației a fost configurată",
     "Conversation picture deleted" : "Imaginea conversației a fost ștearsă",
     "Error while uploading file \"{fileName}\"" : "Eroare la încărcarea fișierului \"{fileName}\"",
@@ -854,14 +849,16 @@ OC.L10N.register(
     "An error happened when trying to share your file" : "Eroare la încercarea de partajare a fișierului",
     "Could not post message: {errorMessage}" : "Nu s-a putut posta mesajul: {errorMessage}",
     "An error occurred while fetching the participants" : "Eroare la preluarea listei de participanți",
+    "Could not send invitation to {actorId}" : "Nu a fost trimisă invitația către {actorId}",
+    "Invitations sent" : "Invitațiile au fost trimise",
     "Failed to join the conversation. Try to reload the page." : "Eroare la încercarea de participare la conversație. Încercați să reîncărcați pagina. ",
     "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Încercați să participați la o conversație având o sesiune activă în altă fereastră sau dispozitiv. Acest lucru nu este suportat în prezent în Nextcloud Talk. Ce doriți să faceți?",
     "Join here" : "Alăturare aici",
     "Leave this page" : "Părăsește pagina",
-    "An error occurred while submitting your vote" : "Eroare la transmiterea votului",
-    "An error occurred while ending the poll" : "Eroare la încheierea votării",
     "An error occurred while requesting assistance" : "Eroare la solicitarea de asistență",
     "An error occurred while resetting the request for assistance" : "Eroare la resetarea solicitării de asistență",
+    "An error occurred while submitting your vote" : "Eroare la transmiterea votului",
+    "An error occurred while ending the poll" : "Eroare la încheierea votării",
     "Failed to add reaction" : "Eroare la adăugarea reacției",
     "Failed to remove reaction" : "Eroare la ștergerea reacției",
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Browserul folosit nu este compatibil cu Nextcloud Talk. Folosiți ultima versiune a Mozilla Firefox, Microsoft Edge, Google Chrome sau Apple Safari.",
@@ -876,10 +873,15 @@ OC.L10N.register(
     "The password is wrong. Try again." : "Parola este incorectă. Încercaţi din nou.",
     "Android app" : "Aplicație Android",
     "iOS app" : "Aplicație iOS",
+    "Call with {user1} and {user2} (Duration {duration})" : "Apel cu {user1} și {user2} (Durată {duration})",
+    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Apelul cu {user1}, {user2} și {user3} (Durată {duration})",
+    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Apel cu {user1}, {user2}, {user3} și {user4} (Durată {duration})",
+    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Apel cu {user1}, {user2}, {user3}, {user4} și {user5} (Durată {duration})",
     "More unread mentions" : "Mai multe menționări necitite",
     "Response to" : "Răspuns la",
     "Enabled for" : "Activat pentru",
     "Moderators" : "Moderatori",
+    "The message could not be sent" : "Mesajul nu s-a putut transmite ",
     "Delete Conversation" : "Șterge conversația",
     "Circles" : "Cercuri",
     "Users, groups and circles" : "Utilizatori, grupuri și cercuri",
@@ -889,7 +891,6 @@ OC.L10N.register(
     "Add users, groups or circles" : "Adaugă utilizatori, grupuri și cercuri",
     "Add users or circles" : "Adaugă utilizatori și cercuri",
     "Add groups or circles" : "Adaugă grupuri și cercuri",
-    "Open sidebar" : "Deschide bara laterală",
     "Start a conversation" : "Porniți o conversație",
     "Post to conversation" : "Postare în conversație",
     "Share to conversation" : "Partajare la conversație"
