@@ -2,23 +2,8 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2018 Joas Schilling <coding@schilljs.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2018 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Chat\Parser;
@@ -163,6 +148,12 @@ class SystemMessage implements IEventListener {
 				$participant->getAttendee()->getActorType() === Attendee::ACTOR_USERS &&
 				$currentActorId === $parsedParameters['actor']['id'] &&
 				empty($parsedParameters['actor']['server']);
+		} elseif ($participant->getAttendee()->getActorType() === Attendee::ACTOR_EMAILS) {
+			$currentActorType = $participant->getAttendee()->getActorType();
+			$currentActorId = $participant->getAttendee()->getActorId();
+			$currentUserIsActor = $parsedParameters['actor']['type'] === 'email' &&
+				$participant->getAttendee()->getActorType() === Attendee::ACTOR_EMAILS &&
+				$participant->getAttendee()->getActorId() === $parsedParameters['actor']['id'];
 		} else {
 			$currentActorType = $participant->getAttendee()->getActorType();
 			$currentActorId = $participant->getAttendee()->getActorId();
@@ -182,7 +173,7 @@ class SystemMessage implements IEventListener {
 				$parsedMessage = $this->l->t('You created the conversation');
 			} elseif ($systemIsActor) {
 				$parsedMessage = $this->l->t('System created the conversation');
-			}if ($cliIsActor) {
+			} elseif ($cliIsActor) {
 				$parsedMessage = $this->l->t('An administrator created the conversation');
 			}
 		} elseif ($message === 'conversation_renamed') {
@@ -235,7 +226,7 @@ class SystemMessage implements IEventListener {
 		} elseif ($message === 'call_missed') {
 			[$parsedMessage, $parsedParameters, $message] = $this->parseMissedCall($room, $parameters, $currentActorType === Attendee::ACTOR_FEDERATED_USERS ? null : $currentActorId);
 		} elseif ($message === 'call_ended' || $message === 'call_ended_everyone') {
-			[$parsedMessage, $parsedParameters] = $this->parseCall($message, $parameters, $parsedParameters);
+			[$parsedMessage, $parsedParameters] = $this->parseCall($room, $message, $parameters, $parsedParameters);
 		} elseif ($message === 'read_only_off') {
 			$parsedMessage = $this->l->t('{actor} unlocked the conversation');
 			if ($currentUserIsActor) {
@@ -366,9 +357,7 @@ class SystemMessage implements IEventListener {
 			$parsedMessage = $this->l->t('{actor} invited {federated_user}');
 			if ($currentUserIsActor) {
 				$parsedMessage = $this->l->t('You invited {federated_user}');
-				if (isset($parsedParameters['federated_user']['server'], $parsedParameters['actor']['server'])
-					&& $parsedParameters['federated_user']['id'] === $parsedParameters['actor']['id']
-					&& $parsedParameters['federated_user']['server'] === $parsedParameters['actor']['server']) {
+				if ($this->isFederatedUserThemselvesActor($parsedParameters['federated_user'], $parsedParameters['actor'])) {
 					$parsedMessage = $this->l->t('You accepted the invitation');
 				}
 			} elseif ($this->isCurrentParticipantChangedUser($currentActorType, $currentActorId, $parsedParameters['federated_user'])) {
@@ -378,9 +367,7 @@ class SystemMessage implements IEventListener {
 				}
 			} elseif ($cliIsActor) {
 				$parsedMessage = $this->l->t('An administrator invited {federated_user}');
-			} elseif (isset($parsedParameters['federated_user']['server'], $parsedParameters['actor']['server'])
-				&& $parsedParameters['federated_user']['id'] === $parsedParameters['actor']['id']
-				&& $parsedParameters['federated_user']['server'] === $parsedParameters['actor']['server']) {
+			} elseif ($this->isFederatedUserThemselvesActor($parsedParameters['federated_user'], $parsedParameters['actor'])) {
 				$parsedMessage = $this->l->t('{federated_user} accepted the invitation');
 			}
 		} elseif ($message === 'federated_user_removed') {
@@ -388,6 +375,9 @@ class SystemMessage implements IEventListener {
 			$parsedMessage = $this->l->t('{actor} removed {federated_user}');
 			if ($currentUserIsActor) {
 				$parsedMessage = $this->l->t('You removed {federated_user}');
+				if ($this->isFederatedUserThemselvesActor($parsedParameters['federated_user'], $parsedParameters['actor'])) {
+					$parsedMessage = $this->l->t('You declined the invitation');
+				}
 			} elseif ($this->isCurrentParticipantChangedUser($currentActorType, $currentActorId, $parsedParameters['federated_user'])) {
 				$parsedMessage = $this->l->t('{actor} removed you');
 				if ($cliIsActor) {
@@ -395,9 +385,7 @@ class SystemMessage implements IEventListener {
 				}
 			} elseif ($cliIsActor) {
 				$parsedMessage = $this->l->t('An administrator removed {federated_user}');
-			} elseif (isset($parsedParameters['federated_user']['server'], $parsedParameters['actor']['server'])
-				&& $parsedParameters['federated_user']['id'] === $parsedParameters['actor']['id']
-				&& $parsedParameters['federated_user']['server'] === $parsedParameters['actor']['server']) {
+			} elseif ($this->isFederatedUserThemselvesActor($parsedParameters['federated_user'], $parsedParameters['actor'])) {
 				$parsedMessage = $this->l->t('{federated_user} declined the invitation');
 			}
 		} elseif ($message === 'group_added') {
@@ -475,7 +463,12 @@ class SystemMessage implements IEventListener {
 				$parsedMessage = $this->l->t('An administrator demoted {user} from moderator');
 			}
 		} elseif ($message === 'guest_moderator_promoted') {
-			$parsedParameters['user'] = $this->getGuest($room, Attendee::ACTOR_GUESTS, $parameters['session']);
+			if (isset($parameters['type'], $parameters['id'])) {
+				$parsedParameters['user'] = $this->getGuest($room, $parameters['type'], $parameters['id']);
+			} else {
+				// Before Nextcloud 30
+				$parsedParameters['user'] = $this->getGuest($room, Attendee::ACTOR_GUESTS, $parameters['session']);
+			}
 			$parsedMessage = $this->l->t('{actor} promoted {user} to moderator');
 			if ($currentUserIsActor) {
 				$parsedMessage = $this->l->t('You promoted {user} to moderator');
@@ -488,7 +481,12 @@ class SystemMessage implements IEventListener {
 				$parsedMessage = $this->l->t('An administrator promoted {user} to moderator');
 			}
 		} elseif ($message === 'guest_moderator_demoted') {
-			$parsedParameters['user'] = $this->getGuest($room, Attendee::ACTOR_GUESTS, $parameters['session']);
+			if (isset($parameters['type'], $parameters['id'])) {
+				$parsedParameters['user'] = $this->getGuest($room, $parameters['type'], $parameters['id']);
+			} else {
+				// Before Nextcloud 30
+				$parsedParameters['user'] = $this->getGuest($room, Attendee::ACTOR_GUESTS, $parameters['session']);
+			}
 			$parsedMessage = $this->l->t('{actor} demoted {user} from moderator');
 			if ($currentUserIsActor) {
 				$parsedMessage = $this->l->t('You demoted {user} from moderator');
@@ -539,7 +537,7 @@ class SystemMessage implements IEventListener {
 			}
 		} elseif ($message === 'object_shared') {
 			$parsedParameters['object'] = $parameters['metaData'];
-			$parsedParameters['object']['id'] = (string) $parsedParameters['object']['id'];
+			$parsedParameters['object']['id'] = (string)$parsedParameters['object']['id'];
 			$parsedMessage = '{object}';
 
 			if (isset($parsedParameters['object']['type'])
@@ -591,10 +589,10 @@ class SystemMessage implements IEventListener {
 				$parsedMessage = $this->l->t('You deleted a reaction');
 			}
 		} elseif ($message === 'message_expiration_enabled') {
-			$weeks = $parameters['seconds'] >= (86400 * 7) ? (int) round($parameters['seconds'] / (86400 * 7)) : 0;
-			$days = $parameters['seconds'] >= 86400 ? (int) round($parameters['seconds'] / 86400) : 0;
-			$hours = $parameters['seconds'] >= 3600 ? (int) round($parameters['seconds'] / 3600) : 0;
-			$minutes = (int) round($parameters['seconds'] / 60);
+			$weeks = $parameters['seconds'] >= (86400 * 7) ? (int)round($parameters['seconds'] / (86400 * 7)) : 0;
+			$days = $parameters['seconds'] >= 86400 ? (int)round($parameters['seconds'] / 86400) : 0;
+			$hours = $parameters['seconds'] >= 3600 ? (int)round($parameters['seconds'] / 3600) : 0;
+			$minutes = (int)round($parameters['seconds'] / 60);
 
 			if ($currentUserIsActor) {
 				if ($weeks > 0) {
@@ -639,7 +637,7 @@ class SystemMessage implements IEventListener {
 			}
 		} elseif ($message === 'poll_closed') {
 			$parsedParameters['poll'] = $parameters['poll'];
-			$parsedParameters['poll']['id'] = (string) $parsedParameters['poll']['id'];
+			$parsedParameters['poll']['id'] = (string)$parsedParameters['poll']['id'];
 			$parsedMessage = $this->l->t('{actor} ended the poll {poll}');
 			if ($currentUserIsActor) {
 				$parsedMessage = $this->l->t('You ended the poll {poll}');
@@ -668,7 +666,7 @@ class SystemMessage implements IEventListener {
 			$parsedMessage = $this->l->t('The recording failed');
 		} elseif ($message === 'poll_voted') {
 			$parsedParameters['poll'] = $parameters['poll'];
-			$parsedParameters['poll']['id'] = (string) $parsedParameters['poll']['id'];
+			$parsedParameters['poll']['id'] = (string)$parsedParameters['poll']['id'];
 			$parsedMessage = $this->l->t('Someone voted on the poll {poll}');
 			unset($parsedParameters['actor']);
 
@@ -717,7 +715,8 @@ class SystemMessage implements IEventListener {
 		} elseif (!$participant->isGuest()) {
 			$currentUserIsActor = $parsedParameters['actor']['type'] === 'user' &&
 				$participant->getAttendee()->getActorType() === Attendee::ACTOR_USERS &&
-				$participant->getAttendee()->getActorId() === $parsedParameters['actor']['id'];
+				$participant->getAttendee()->getActorId() === $parsedParameters['actor']['id'] &&
+				empty($parsedParameters['actor']['server']);
 		} else {
 			$currentUserIsActor = $parsedParameters['actor']['type'] === 'guest' &&
 				$participant->getAttendee()->getActorType() === 'guest' &&
@@ -753,7 +752,7 @@ class SystemMessage implements IEventListener {
 	 * @throws ShareNotFound
 	 */
 	protected function getFileFromShare(Room $room, ?Participant $participant, string $shareId): array {
-		$share = $this->shareProvider->getShareById((int) $shareId);
+		$share = $this->shareProvider->getShareById((int)$shareId);
 
 		if ($participant && $participant->getAttendee()->getActorType() === Attendee::ACTOR_USERS) {
 			if ($share->getShareOwner() !== $participant->getAttendee()->getActorId()) {
@@ -815,13 +814,13 @@ class SystemMessage implements IEventListener {
 
 		$data = [
 			'type' => 'file',
-			'id' => (string) $fileId,
+			'id' => (string)$fileId,
 			'name' => $name,
-			'size' => (string) $size,
+			'size' => (string)$size,
 			'path' => $path,
 			'link' => $url,
 			'etag' => $node->getEtag(),
-			'permissions' => (string) $node->getPermissions(),
+			'permissions' => (string)$node->getPermissions(),
 			'mimetype' => $node->getMimeType(),
 			'preview-available' => $isPreviewAvailable ? 'yes' : 'no',
 		];
@@ -829,10 +828,14 @@ class SystemMessage implements IEventListener {
 		// If a preview is available, check if we can get the dimensions of the file from the metadata API
 		if ($isPreviewAvailable && str_starts_with($node->getMimeType(), 'image/')) {
 			try {
-				$sizeMetadata = $this->metadataCache->getMetadataPhotosSizeForFileId($fileId);
+				$sizeMetadata = $this->metadataCache->getImageMetadataForFileId($fileId);
 				if (isset($sizeMetadata['width'], $sizeMetadata['height'])) {
-					$data['width'] = (string) $sizeMetadata['width'];
-					$data['height'] = (string) $sizeMetadata['height'];
+					$data['width'] = (string)$sizeMetadata['width'];
+					$data['height'] = (string)$sizeMetadata['height'];
+				}
+
+				if (isset($sizeMetadata['blurhash'])) {
+					$data['blurhash'] = $sizeMetadata['blurhash'];
 				}
 			} catch (FilesMetadataNotFoundException) {
 			}
@@ -843,7 +846,7 @@ class SystemMessage implements IEventListener {
 
 			$vObject = Reader::read($vCard);
 			if (!empty($vObject->FN)) {
-				$data['contact-name'] = (string) $vObject->FN;
+				$data['contact-name'] = (string)$vObject->FN;
 			}
 
 			$photo = $this->photoCache->getPhotoFromVObject($vObject);
@@ -860,6 +863,9 @@ class SystemMessage implements IEventListener {
 		if ($currentActorType === Attendee::ACTOR_GUESTS) {
 			return $parameter['type'] === 'guest' && $currentActorId === $parameter['id'];
 		}
+		if ($currentActorType === Attendee::ACTOR_EMAILS) {
+			return $parameter['type'] === 'guest' && 'email/' . $currentActorId === $parameter['id'];
+		}
 
 		if (isset($parameter['server'])
 			&& $currentActorType === Attendee::ACTOR_FEDERATED_USERS
@@ -868,7 +874,13 @@ class SystemMessage implements IEventListener {
 				&& $this->currentFederatedUserDetails['server'] === $parameter['server'];
 		}
 
-		return $currentActorType === Attendee::ACTOR_USERS && $parameter['type'] === 'user' && $currentActorId === $parameter['id'];
+		return $currentActorType === Attendee::ACTOR_USERS && $parameter['type'] === 'user' && $currentActorId === $parameter['id'] && empty($parameter['server']);
+	}
+
+	protected function isFederatedUserThemselvesActor(array $federated, array $actor): bool {
+		return isset($federated['server'], $actor['server'])
+			&& $federated['id'] === $actor['id']
+			&& $federated['server'] === $actor['server'];
 	}
 
 	protected function getActorFromComment(Room $room, IComment $comment): array {
@@ -980,7 +992,7 @@ class SystemMessage implements IEventListener {
 			'type' => 'circle',
 			'id' => $circleId,
 			'name' => $this->circleNames[$circleId],
-			'url' => $this->circleLinks[$circleId],
+			'link' => $this->circleLinks[$circleId],
 		];
 	}
 
@@ -1026,7 +1038,7 @@ class SystemMessage implements IEventListener {
 
 		return [
 			'type' => 'guest',
-			'id' => 'guest/' . $actorId,
+			'id' => ($actorType === Attendee::ACTOR_GUESTS ? 'guest/' : 'email/') . $actorId,
 			'name' => $this->guestNames[$key],
 		];
 	}
@@ -1094,59 +1106,96 @@ class SystemMessage implements IEventListener {
 	}
 
 
-	protected function parseCall(string $message, array $parameters, array $params): array {
+	protected function parseCall(Room $room, string $message, array $parameters, array $params): array {
+		$actorIsSystem = $params['actor']['type'] === 'guest' && $params['actor']['id'] === 'guest/' . Attendee::ACTOR_ID_SYSTEM;
 		if ($message === 'call_ended_everyone') {
 			if ($params['actor']['type'] === 'user') {
 				$entry = array_keys($parameters['users'], $params['actor']['id'], true);
 				foreach ($entry as $i) {
 					unset($parameters['users'][$i]);
 				}
-			} else {
+			} elseif (!$actorIsSystem) {
 				$parameters['guests']--;
 			}
 		}
+		if (!isset($parameters['cloudIds'])) {
+			// Compatibility with old messages
+			$parameters['cloudIds'] = [];
+		}
 		sort($parameters['users']);
-		$numUsers = \count($parameters['users']);
+		sort($parameters['cloudIds']);
+
+		$numRealUsers = count($parameters['users']);
+		$numUsers = $numRealUsers + count($parameters['cloudIds']);
 		$displayedUsers = $numUsers;
 
 		switch ($numUsers) {
 			case 0:
-				if ($message === 'call_ended') {
-					$subject = $this->l->n(
-						'Call with %n guest (Duration {duration})',
-						'Call with %n guests (Duration {duration})',
-						$parameters['guests']
-					);
+				if ($parameters['guests'] === 0) {
+					// Call without users and guests
+					if ($actorIsSystem) {
+						$subject = $this->l->t('Call was ended, as it reached the maximum call duration (Duration {duration})');
+					} elseif ($message === 'call_ended') {
+						$subject = $this->l->t('Call ended (Duration {duration})');
+					} else {
+						$subject = $this->l->t('{actor} ended the call (Duration {duration})');
+					}
 				} else {
-					$subject = $this->l->n(
-						'{actor} ended the call with %n guest (Duration {duration})',
-						'{actor} ended the call with %n guests (Duration {duration})',
-						$parameters['guests']
-					);
+					if ($actorIsSystem) {
+						$subject = $this->l->n(
+							'Call with %n guest was ended, as it reached the maximum call duration (Duration {duration})',
+							'Call with %n guests was ended, as it reached the maximum call duration (Duration {duration})',
+							$parameters['guests']
+						);
+					} elseif ($message === 'call_ended') {
+						$subject = $this->l->n(
+							'Call with %n guest ended (Duration {duration})',
+							'Call with %n guests ended (Duration {duration})',
+							$parameters['guests']
+						);
+					} else {
+						$subject = $this->l->n(
+							'{actor} ended the call with %n guest (Duration {duration})',
+							'{actor} ended the call with %n guests (Duration {duration})',
+							$parameters['guests']
+						);
+					}
 				}
 				break;
 			case 1:
-				if ($message === 'call_ended') {
-					$subject = $this->l->t('Call with {user1} and {user2} (Duration {duration})');
-				} else {
-					if ($parameters['guests'] === 0) {
+				if ($parameters['guests'] === 0) {
+					if ($actorIsSystem) {
+						$subject = $this->l->t('Call with {user1} was ended, as it reached the maximum call duration (Duration {duration})');
+					} elseif ($message === 'call_ended') {
+						$subject = $this->l->t('Call with {user1} ended (Duration {duration})');
+					} else {
 						$subject = $this->l->t('{actor} ended the call with {user1} (Duration {duration})');
+					}
+				} else {
+					if ($actorIsSystem) {
+						$subject = $this->l->t('Call with {user1} and {user2} was ended, as it reached the maximum call duration (Duration {duration})');
+					} elseif ($message === 'call_ended') {
+						$subject = $this->l->t('Call with {user1} and {user2} ended (Duration {duration})');
 					} else {
 						$subject = $this->l->t('{actor} ended the call with {user1} and {user2} (Duration {duration})');
 					}
+					$subject = str_replace('{user2}', $this->l->n('%n guest', '%n guests', $parameters['guests']), $subject);
 				}
-				$subject = str_replace('{user2}', $this->l->n('%n guest', '%n guests', $parameters['guests']), $subject);
 				break;
 			case 2:
 				if ($parameters['guests'] === 0) {
-					if ($message === 'call_ended') {
-						$subject = $this->l->t('Call with {user1} and {user2} (Duration {duration})');
+					if ($actorIsSystem) {
+						$subject = $this->l->t('Call with {user1} and {user2} was ended, as it reached the maximum call duration (Duration {duration})');
+					} elseif ($message === 'call_ended') {
+						$subject = $this->l->t('Call with {user1} and {user2} ended (Duration {duration})');
 					} else {
 						$subject = $this->l->t('{actor} ended the call with {user1} and {user2} (Duration {duration})');
 					}
 				} else {
-					if ($message === 'call_ended') {
-						$subject = $this->l->t('Call with {user1}, {user2} and {user3} (Duration {duration})');
+					if ($actorIsSystem) {
+						$subject = $this->l->t('Call with {user1}, {user2} and {user3} was ended, as it reached the maximum call duration (Duration {duration})');
+					} elseif ($message === 'call_ended') {
+						$subject = $this->l->t('Call with {user1}, {user2} and {user3} ended (Duration {duration})');
 					} else {
 						$subject = $this->l->t('{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})');
 					}
@@ -1155,14 +1204,18 @@ class SystemMessage implements IEventListener {
 				break;
 			case 3:
 				if ($parameters['guests'] === 0) {
-					if ($message === 'call_ended') {
-						$subject = $this->l->t('Call with {user1}, {user2} and {user3} (Duration {duration})');
+					if ($actorIsSystem) {
+						$subject = $this->l->t('Call with {user1}, {user2} and {user3} was ended, as it reached the maximum call duration (Duration {duration})');
+					} elseif ($message === 'call_ended') {
+						$subject = $this->l->t('Call with {user1}, {user2} and {user3} ended (Duration {duration})');
 					} else {
 						$subject = $this->l->t('{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})');
 					}
 				} else {
-					if ($message === 'call_ended') {
-						$subject = $this->l->t('Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})');
+					if ($actorIsSystem) {
+						$subject = $this->l->t('Call with {user1}, {user2}, {user3} and {user4} was ended, as it reached the maximum call duration (Duration {duration})');
+					} elseif ($message === 'call_ended') {
+						$subject = $this->l->t('Call with {user1}, {user2}, {user3} and {user4} ended (Duration {duration})');
 					} else {
 						$subject = $this->l->t('{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})');
 					}
@@ -1171,14 +1224,18 @@ class SystemMessage implements IEventListener {
 				break;
 			case 4:
 				if ($parameters['guests'] === 0) {
-					if ($message === 'call_ended') {
-						$subject = $this->l->t('Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})');
+					if ($actorIsSystem) {
+						$subject = $this->l->t('Call with {user1}, {user2}, {user3} and {user4} was ended, as it reached the maximum call duration (Duration {duration})');
+					} elseif ($message === 'call_ended') {
+						$subject = $this->l->t('Call with {user1}, {user2}, {user3} and {user4} ended (Duration {duration})');
 					} else {
 						$subject = $this->l->t('{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})');
 					}
 				} else {
-					if ($message === 'call_ended') {
-						$subject = $this->l->t('Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})');
+					if ($actorIsSystem) {
+						$subject = $this->l->t('Call with {user1}, {user2}, {user3}, {user4} and {user5} was ended, as it reached the maximum call duration (Duration {duration})');
+					} elseif ($message === 'call_ended') {
+						$subject = $this->l->t('Call with {user1}, {user2}, {user3}, {user4} and {user5} ended (Duration {duration})');
 					} else {
 						$subject = $this->l->t('{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})');
 					}
@@ -1187,8 +1244,10 @@ class SystemMessage implements IEventListener {
 				break;
 			case 5:
 			default:
-				if ($message === 'call_ended') {
-					$subject = $this->l->t('Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})');
+				if ($actorIsSystem) {
+					$subject = $this->l->t('Call with {user1}, {user2}, {user3}, {user4} and {user5} was ended, as it reached the maximum call duration (Duration {duration})');
+				} elseif ($message === 'call_ended') {
+					$subject = $this->l->t('Call with {user1}, {user2}, {user3}, {user4} and {user5} ended (Duration {duration})');
 				} else {
 					$subject = $this->l->t('{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})');
 				}
@@ -1203,7 +1262,11 @@ class SystemMessage implements IEventListener {
 
 		if ($displayedUsers > 0) {
 			for ($i = 1; $i <= $displayedUsers; $i++) {
-				$params['user' . $i] = $this->getUser($parameters['users'][$i - 1]);
+				if ($i <= $numRealUsers) {
+					$params['user' . $i] = $this->getUser($parameters['users'][$i - 1]);
+				} else {
+					$params['user' . $i] = $this->getRemoteUser($room, $parameters['cloudIds'][$i - $numRealUsers - 1]);
+				}
 			}
 		}
 
