@@ -2,27 +2,8 @@
 
 declare(strict_types=1);
 /**
- *
- * @copyright Copyright (c) 2023 Joas Schilling <coding@schilljs.com>
- * @copyright Copyright (c) 2017, Daniel Calviño Sánchez (danxuliu@gmail.com)
- *
- * @author Joas Schilling <coding@schilljs.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2017 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Chat\Parser;
@@ -109,8 +90,13 @@ class UserMention implements IEventListener {
 			return mb_strlen($m2['id']) <=> mb_strlen($m1['id']);
 		});
 
+		$metadata = $comment->getMetaData() ?? [];
 		foreach ($mentions as $mention) {
 			if ($mention['type'] === 'user' && $mention['id'] === 'all') {
+				if (!isset($metadata[Message::METADATA_CAN_MENTION_ALL])) {
+					continue;
+				}
+
 				$mention['type'] = 'call';
 			}
 
@@ -128,6 +114,7 @@ class UserMention implements IEventListener {
 
 			$search = $mention['id'];
 			if (
+				$mention['type'] === 'email' ||
 				$mention['type'] === 'group' ||
 				// $mention['type'] === 'federated_group' ||
 				// $mention['type'] === 'team' ||
@@ -145,6 +132,7 @@ class UserMention implements IEventListener {
 			$message = str_replace('@"' . $search . '"', '{' . $mentionParameterId . '}', $message);
 			if (!str_contains($search, ' ')
 				&& !str_starts_with($search, 'guest/')
+				&& !str_starts_with($search, 'email/')
 				&& !str_starts_with($search, 'group/')
 				// && !str_starts_with($search, 'federated_group/')
 				// && !str_starts_with($search, 'team/')
@@ -174,6 +162,19 @@ class UserMention implements IEventListener {
 					$displayName = $this->l->t('Guest');
 				}
 
+				$messageParameters[$mentionParameterId] = [
+					'type' => $mention['type'],
+					'id' => $mention['id'],
+					'name' => $displayName,
+				];
+			} elseif ($mention['type'] === 'email') {
+				try {
+					$participant = $this->participantService->getParticipantByActor($chatMessage->getRoom(), Attendee::ACTOR_EMAILS, $mention['id']);
+					$displayName = $participant->getAttendee()->getDisplayName() ?: $this->l->t('Guest');
+				} catch (ParticipantNotFoundException) {
+					$displayName = $this->l->t('Guest');
+				}
+
 				$messageParameters[$mentionParameterId] = [
 					'type' => $mention['type'],
 					'id' => $mention['id'],
