@@ -2,25 +2,8 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2023 Joas Schilling <coding@schilljs.com>
- *
- * @author Joas Schilling <coding@schilljs.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2023 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Chat\SystemMessage;
@@ -328,7 +311,11 @@ class Listener implements IEventListener {
 		$room = $event->getRoom();
 		$attendee = $event->getParticipant()->getAttendee();
 
-		if ($attendee->getActorType() !== Attendee::ACTOR_USERS && $attendee->getActorType() !== Attendee::ACTOR_GUESTS) {
+		if (!in_array($attendee->getActorType(), [
+			Attendee::ACTOR_USERS,
+			Attendee::ACTOR_EMAILS,
+			Attendee::ACTOR_GUESTS,
+		], true)) {
 			return;
 		}
 
@@ -341,9 +328,9 @@ class Listener implements IEventListener {
 				$this->sendSystemMessage($room, 'moderator_demoted', ['user' => $attendee->getActorId()]);
 			}
 		} elseif ($event->getNewValue() === Participant::GUEST_MODERATOR) {
-			$this->sendSystemMessage($room, 'guest_moderator_promoted', ['session' => $attendee->getActorId()]);
+			$this->sendSystemMessage($room, 'guest_moderator_promoted', ['type' => $attendee->getActorType(), 'id' => $attendee->getActorId()]);
 		} elseif ($event->getNewValue() === Participant::GUEST) {
-			$this->sendSystemMessage($room, 'guest_moderator_demoted', ['session' => $attendee->getActorId()]);
+			$this->sendSystemMessage($room, 'guest_moderator_demoted', ['type' => $attendee->getActorType(), 'id' => $attendee->getActorId()]);
 		}
 	}
 
@@ -399,7 +386,7 @@ class Listener implements IEventListener {
 		}
 
 		if (isset($metaData[Message::METADATA_SILENT])) {
-			$silent = (bool) $metaData[Message::METADATA_SILENT];
+			$silent = (bool)$metaData[Message::METADATA_SILENT];
 		} else {
 			$silent = false;
 		}
@@ -471,14 +458,14 @@ class Listener implements IEventListener {
 		// the system message left for the share in the chat.
 		$referenceId = $this->request->getParam('referenceId', null);
 		if ($referenceId !== null) {
-			$referenceId = (string) $referenceId;
+			$referenceId = (string)$referenceId;
 		}
 
 		$parent = null;
 		$replyTo = $parameters['metaData']['replyTo'] ?? null;
 		if ($replyTo !== null) {
 			try {
-				$parentComment = $this->chatManager->getParentComment($room, (string) $replyTo);
+				$parentComment = $this->chatManager->getParentComment($room, (string)$replyTo);
 				$parentMessage = $this->messageParser->createMessage($room, $participant, $parentComment, $this->l);
 				$this->messageParser->parseMessage($parentMessage);
 				if ($parentMessage->isReplyable()) {
