@@ -2,30 +2,17 @@
 
 declare(strict_types=1);
 /**
- * @author Joachim Bauch <mail@joachim-bauch.de>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2017 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk;
 
 use OCA\Talk\Events\BeforeTurnServersGetEvent;
+use OCA\Talk\Federation\Authenticator;
 use OCA\Talk\Model\Attendee;
 use OCA\Talk\Service\RecordingService;
+use OCA\Talk\Settings\UserPreference;
 use OCA\Talk\Vendor\Firebase\JWT\JWT;
 use OCP\AppFramework\Services\IAppConfig;
 use OCP\AppFramework\Utility\ITimeFactory;
@@ -76,19 +63,30 @@ class Config {
 		return \is_array($groups) ? $groups : [];
 	}
 
+	/**
+	 * @return Participant::PRIVACY_*
+	 */
 	public function getUserReadPrivacy(string $userId): int {
-		return (int) $this->config->getUserValue(
+		return match ((int)$this->config->getUserValue(
 			$userId,
 			'spreed', 'read_status_privacy',
-			(string) Participant::PRIVACY_PUBLIC);
+			(string)Participant::PRIVACY_PUBLIC)) {
+			Participant::PRIVACY_PUBLIC => Participant::PRIVACY_PUBLIC,
+			default => Participant::PRIVACY_PRIVATE,
+		};
 	}
 
+	/**
+	 * @return Participant::PRIVACY_*
+	 */
 	public function getUserTypingPrivacy(string $userId): int {
-		return (int) $this->config->getUserValue(
+		return match ((int)$this->config->getUserValue(
 			$userId,
 			'spreed', 'typing_privacy',
-			(string) Participant::PRIVACY_PUBLIC);
-
+			(string)Participant::PRIVACY_PUBLIC)) {
+			Participant::PRIVACY_PUBLIC => Participant::PRIVACY_PUBLIC,
+			default => Participant::PRIVACY_PRIVATE,
+		};
 	}
 
 	/**
@@ -223,7 +221,7 @@ class Config {
 	 * @return RecordingService::CONSENT_REQUIRED_*
 	 */
 	public function getRecordingConsentConfig(): int {
-		return match ((int) $this->config->getAppValue('spreed', 'recording_consent', (string) RecordingService::CONSENT_REQUIRED_NO)) {
+		return match ((int)$this->config->getAppValue('spreed', 'recording_consent', (string)RecordingService::CONSENT_REQUIRED_NO)) {
 			RecordingService::CONSENT_REQUIRED_YES => RecordingService::CONSENT_REQUIRED_YES,
 			RecordingService::CONSENT_REQUIRED_OPTIONAL => RecordingService::CONSENT_REQUIRED_OPTIONAL,
 			default => RecordingService::CONSENT_REQUIRED_NO,
@@ -268,11 +266,15 @@ class Config {
 		return empty(array_intersect($allowedGroups, $userGroups));
 	}
 
+	/**
+	 * @return int<0, 255>
+	 * @psalm-return int-mask-of<Attendee::PERMISSIONS_*>
+	 */
 	public function getDefaultPermissions(): int {
 		// Admin configured default permissions
 		$configurableDefault = $this->config->getAppValue('spreed', 'default_permissions');
 		if ($configurableDefault !== '') {
-			return (int) $configurableDefault;
+			return min(Attendee::PERMISSIONS_MAX_CUSTOM, max(Attendee::PERMISSIONS_DEFAULT, (int)$configurableDefault));
 		}
 
 		// Falling back to an unrestricted set of permissions, only ignoring the lobby is off
@@ -474,12 +476,11 @@ class Config {
 	 * @param string|null $userId
 	 * @return string
 	 */
-	public function getSignalingTicket(int $version, ?string $userId): string {
+	public function getSignalingTicket(int $version, ?string $userId, ?string $cloudId = null): string {
 		switch ($version) {
-			case self::SIGNALING_TICKET_V1:
-				return $this->getSignalingTicketV1($userId);
 			case self::SIGNALING_TICKET_V2:
-				return $this->getSignalingTicketV2($userId);
+				return $this->getSignalingTicketV2($userId, $cloudId);
+			case self::SIGNALING_TICKET_V1:
 			default:
 				return $this->getSignalingTicketV1($userId);
 		}
@@ -586,21 +587,40 @@ class Config {
 		];
 	}
 
+	public function getSignalingFederatedUserData(): array {
+		/** @var Authenticator $authenticator */
+		$authenticator = \OCP\Server::get(Authenticator::class);
+		if (!$authenticator->isFederationRequest()) {
+			return [];
+		}
+
+		return [
+			'displayname' => $authenticator->getParticipant()->getAttendee()->getDisplayName(),
+		];
+	}
+
 	/**
-	 * @param string|null $userId
+	 * @param string|null $userId if given, the id of a user in this instance or
+	 *                            a cloud id.
 	 * @return string
 	 */
-	private function getSignalingTicketV2(?string $userId): string {
+	private function getSignalingTicketV2(?string $userId, ?string $cloudId): string {
 		$timestamp = $this->timeFactory->getTime();
 		$data = [
 			'iss' => $this->urlGenerator->getAbsoluteURL(''),
 			'iat' => $timestamp,
 			'exp' => $timestamp + 60,  // Valid for 1 minute.
 		];
-		$user = !empty($userId) ? $this->userManager->get($userId) : null;
+		$user = $userId !== null ? $this->userManager->get($userId) : null;
 		if ($user instanceof IUser) {
 			$data['sub'] = $user->getUID();
 			$data['userdata'] = $this->getSignalingUserData($user);
+		} elseif ($cloudId !== null && $cloudId !== '') {
+			$data['sub'] = $cloudId;
+			$extendedData = $this->getSignalingFederatedUserData();
+			if (!empty($extendedData)) {
+				$data['userdata'] = $extendedData;
+			}
 		}
 
 		$alg = $this->getSignalingTokenAlgorithm();
@@ -637,10 +657,41 @@ class Config {
 	}
 
 	public function getGridVideosLimit(): int {
-		return (int) $this->config->getAppValue('spreed', 'grid_videos_limit', '19'); // 5*4 - self
+		return (int)$this->config->getAppValue('spreed', 'grid_videos_limit', '19'); // 5*4 - self
 	}
 
 	public function getGridVideosLimitEnforced(): bool {
 		return $this->config->getAppValue('spreed', 'grid_videos_limit_enforced', 'no') === 'yes';
 	}
+
+	/**
+	 * User setting falling back to admin defined app config
+	 *
+	 * @param ?string $userId
+	 * @return bool
+	 */
+	public function getCallsStartWithoutMedia(?string $userId): bool {
+		if ($userId !== null) {
+			$userSetting = $this->config->getUserValue($userId, 'spreed', UserPreference::CALLS_START_WITHOUT_MEDIA);
+			if ($userSetting === 'yes' || $userSetting === 'no') {
+				return $userSetting === 'yes';
+			}
+		}
+
+		return $this->appConfig->getAppValueBool('calls_start_without_media');
+	}
+
+	/**
+	 * User setting for blur background
+	 *
+	 * @param ?string $userId
+	 * @return bool
+	 */
+	public function getBlurVirtualBackground(?string $userId): bool {
+		if ($userId !== null) {
+			$userSetting = $this->config->getUserValue($userId, 'spreed', UserPreference::BLUR_VIRTUAL_BACKGROUND);
+			return $userSetting === 'yes';
+		}
+		return false;
+	}
 }
