@@ -2,28 +2,8 @@
 
 declare(strict_types=1);
 /**
- *
- * @copyright Copyright (c) 2018, Daniel Calviño Sánchez (danxuliu@gmail.com)
- *
- * Code copied from "lib/private/Share20/DefaultShareProvider.php" and
- * "apps/sharebymail/lib/ShareByMailProvider.php" at d805959e819e64 in Nextcloud
- * server repository.
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2018 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Share;
@@ -196,7 +176,7 @@ class RoomShareProvider implements IShareProvider {
 		string $target,
 		int $permissions,
 		string $token,
-		?\DateTime $expirationDate
+		?\DateTime $expirationDate,
 	): int {
 		$insert = $this->dbConnection->getQueryBuilder();
 		$insert->insert('share')
@@ -446,7 +426,7 @@ class RoomShareProvider implements IShareProvider {
 
 		$update->executeStatement();
 
-		return $this->getShareById((int) $share->getId(), $recipient);
+		return $this->getShareById((int)$share->getId(), $recipient);
 	}
 
 	/**
@@ -688,7 +668,7 @@ class RoomShareProvider implements IShareProvider {
 			$id = $data['id'];
 			if ($this->isAccessibleResult($data)) {
 				$share = $this->createShareObject($data);
-				$shares[(int) $share->getId()] = $share;
+				$shares[(int)$share->getId()] = $share;
 			} else {
 				$share = false;
 			}
@@ -1023,8 +1003,8 @@ class RoomShareProvider implements IShareProvider {
 	protected function filterSharesOfUser(array $shares): array {
 		// Room shares when the user has a share exception
 		foreach ($shares as $id => $share) {
-			$type = (int) $share['share_type'];
-			$permissions = (int) $share['permissions'];
+			$type = (int)$share['share_type'];
+			$permissions = (int)$share['permissions'];
 
 			if ($type === self::SHARE_TYPE_USERROOM) {
 				unset($shares[$share['parent']]);
@@ -1112,12 +1092,15 @@ class RoomShareProvider implements IShareProvider {
 		$cursor->closeCursor();
 
 		if (!empty($ids)) {
+			$delete = $this->dbConnection->getQueryBuilder();
+			$delete->delete('share')
+				->where($delete->expr()->eq('share_type', $delete->createNamedParameter(self::SHARE_TYPE_USERROOM)))
+				->andWhere($delete->expr()->in('parent', $delete->createParameter('ids')));
+
 			$chunks = array_chunk($ids, 100);
 			foreach ($chunks as $chunk) {
-				$qb->delete('share')
-					->where($qb->expr()->eq('share_type', $qb->createNamedParameter(self::SHARE_TYPE_USERROOM)))
-					->andWhere($qb->expr()->in('parent', $qb->createNamedParameter($chunk, IQueryBuilder::PARAM_INT_ARRAY)));
-				$qb->executeStatement();
+				$delete->setParameter('ids', $chunk, IQueryBuilder::PARAM_INT_ARRAY);
+				$delete->executeStatement();
 			}
 		}
 
